use std::collections::HashMap;

use serde::{Deserialize, Serialize};
use uuid::Uuid;

use super::{FamilyId, PotId};

#[derive(Serialize, Deserialize, Clone, Debug, Default, PartialEq, Eq, PartialOrd, Ord)]
pub struct ShareId(Uuid);
impl ShareId {
    pub fn new() -> Self {
        ShareId(Uuid::new_v4())
    }
}

impl ToString for ShareId {
    fn to_string(&self) -> String {
        self.0.to_string()
    }
}

impl From<&ShareId> for String {
    fn from(value: &ShareId) -> Self {
        value.0.to_string()
    }
}

impl TryFrom<&str> for ShareId {
    type Error = serde_json::Error;
    fn try_from(value: &str) -> Result<Self, Self::Error> {
        serde_json::from_str(value)
    }
}


#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub struct ShareContent {
    pub pots: Vec<PotId>,
}

#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub enum SharePermissions {
    Read,
    ReadWrite,
    Owner
}
#[derive(Serialize, Deserialize, Clone, Debug, PartialEq)]
pub struct Share {
    pub id: ShareId,
    pub content: ShareContent,
    pub members: HashMap<FamilyId, SharePermissions>,
}